# footium_api
python api for footium


## Tutorials

```
pip install footium_api[notebooks]
```

- [setup](./notebooks/setup_notebook.ipynb) run this to set up for your wallets, clubs etc
- [my_players](./notebooks/my_players.ipynb) --> how to get your players
- [next_fixtures](./notebooks/next_fixtures.ipynb) --> get next features for your clubs
- [formations](./notebooks/my_players.ipynb) --> get the formations supported
